summaryrefslogtreecommitdiffstats
path: root/drivers/net/wireless/iwlwifi/iwl-bus.h
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/net/wireless/iwlwifi/iwl-bus.h')
-rw-r--r--drivers/net/wireless/iwlwifi/iwl-bus.h7
1 files changed, 2 insertions, 5 deletions
diff --git a/drivers/net/wireless/iwlwifi/iwl-bus.h b/drivers/net/wireless/iwlwifi/iwl-bus.h
index fef62e6c2c88..f3ee1c0c004c 100644
--- a/drivers/net/wireless/iwlwifi/iwl-bus.h
+++ b/drivers/net/wireless/iwlwifi/iwl-bus.h
@@ -67,10 +67,9 @@ struct iwl_bus;
/**
* struct iwl_bus_ops - bus specific operations
-
* @get_pm_support: must returns true if the bus can go to sleep
* @apm_config: will be called during the config of the APM configuration
* @set_drv_data: set the priv pointer to the bus layer
* @get_hw_id: prints the hw_id in the provided buffer
* @write8: write a byte to register at offset ofs
* @write32: write a dword to register at offset ofs
@@ -88,9 +87,7 @@ struct iwl_bus_ops {
struct iwl_bus {
/* Common data to all buses */
-
- /*TODO: priv should be void * */
- struct iwl_priv *priv; /* driver's context */
+ void *drv_data; /* driver's context */
struct device *dev;
struct iwl_bus_ops *ops;
@@ -67,10 +67,9 @@ struct iwl_bus;
* @get_pm_support: must returns true if the bus can go to sleep
* @apm_config: will be called during the config of the APM configuration
- * @set_drv_data: set the priv pointer to the bus layer
+ * @set_drv_data: set the drv_data pointer to the bus layer
* @get_hw_id: prints the hw_id in the provided buffer
* @write8: write a byte to register at offset ofs